/*
** GLprocs utility for getting function addresses for OpenGL(R) 1.2, 
** OpenGL 1.3, OpenGL 1.4, OpenGL 1.5 and OpenGL extension functions.
**
** Version:  1.1
**
** License Applicability. Except to the extent portions of this file are
** made subject to an alternative license as permitted in the SGI Free
** Software License B, Version 1.1 (the "License"), the contents of this
** file are subject only to the provisions of the License. You may not use
** this file except in compliance with the License. You may obtain a copy
** of the License at Silicon Graphics, Inc., attn: Legal Services, 1600
** Amphitheatre Parkway, Mountain View, CA 94043-1351, or at:
** 
** http://oss.sgi.com/projects/FreeB
** 
** Note that, as provided in the License, the Software is distributed on an
** "AS IS" basis, with ALL EXPRESS AND IMPLIED WARRANTIES AND CONDITIONS
** DISCLAIMED, INCLUDING, WITHOUT LIMITATION, ANY IMPLIED WARRANTIES AND
** CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY, FITNESS FOR A
** PARTICULAR PURPOSE, AND NON-INFRINGEMENT.
** 
** Original Code. The Original Code is: OpenGL Sample Implementation,
** Version 1.2.1, released January 26, 2000, developed by Silicon Graphics,
** Inc. The Original Code is Copyright (c) 1991-2000 Silicon Graphics, Inc.
** Copyright in any portions created by third parties is as indicated
** elsewhere herein. All Rights Reserved.
** 
** Additional Notice Provisions: This software was created using the
** OpenGL(R) version 1.2.1 Sample Implementation published by SGI, but has
** not been independently verified as being compliant with the OpenGL(R)
** version 1.2.1 Specification.
**
** Initial version of glprocs.{c,h} contributed by Intel(R) Corporation.
*/

#include <assert.h>
#include <stdlib.h>

#ifdef USE_EXT_IF

#ifdef _WIN32
  #include <windows.h>
  #include "GL/gl.h"  /* Include local "gl.h". Don't include vc32 <GL/gl.h>. */
  #include <glprocs.h>

#define _ASSERT(a) assert(a)

static HANDLE WINAPI InitCreateBufferRegionARB (HDC hDC, int iLayerPlane, UINT uType)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglCreateBufferRegionARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglCreateBufferRegionARB = extproc;

	return wglCreateBufferRegionARB(hDC, iLayerPlane, uType);
}

static VOID WINAPI InitDeleteBufferRegionARB (HANDLE hRegion)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDeleteBufferRegionARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return;
	}

	wglDeleteBufferRegionARB = extproc;

	wglDeleteBufferRegionARB(hRegion);
}

static BOOL WINAPI InitSaveBufferRegionARB (HANDLE hRegion, int x, int y, int width, int height)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSaveBufferRegionARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSaveBufferRegionARB = extproc;

	return wglSaveBufferRegionARB(hRegion, x, y, width, height);
}

static BOOL WINAPI InitRestoreBufferRegionARB (HANDLE hRegion, int x, int y, int width, int height, int xSrc, int ySrc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglRestoreBufferRegionARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglRestoreBufferRegionARB = extproc;

	return wglRestoreBufferRegionARB(hRegion, x, y, width, height, xSrc, ySrc);
}

static const char * WINAPI InitGetExtensionsStringARB (HDC hdc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetExtensionsStringARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetExtensionsStringARB = extproc;

	return wglGetExtensionsStringARB(hdc);
}

static BOOL WINAPI InitGetPixelFormatAttribivARB (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, const int *piAttributes, int *piValues)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPixelFormatAttribivARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPixelFormatAttribivARB = extproc;

	return wglGetPixelFormatAttribivARB(hdc, iPixelFormat, iLayerPlane, nAttributes, piAttributes, piValues);
}

static BOOL WINAPI InitGetPixelFormatAttribfvARB (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, const int *piAttributes, FLOAT *pfValues)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPixelFormatAttribfvARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPixelFormatAttribfvARB = extproc;

	return wglGetPixelFormatAttribfvARB(hdc, iPixelFormat, iLayerPlane, nAttributes, piAttributes, pfValues);
}

static BOOL WINAPI InitChoosePixelFormatARB (HDC hdc, const int *piAttribIList, const FLOAT *pfAttribFList, UINT nMaxFormats, int *piFormats, UINT *nNumFormats)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglChoosePixelFormatARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglChoosePixelFormatARB = extproc;

	return wglChoosePixelFormatARB(hdc, piAttribIList, pfAttribFList, nMaxFormats, piFormats, nNumFormats);
}

static BOOL WINAPI InitMakeContextCurrentARB (HDC hDrawDC, HDC hReadDC, HGLRC hglrc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglMakeContextCurrentARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglMakeContextCurrentARB = extproc;

	return wglMakeContextCurrentARB(hDrawDC, hReadDC, hglrc);
}

static HDC WINAPI InitGetCurrentReadDCARB (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetCurrentReadDCARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetCurrentReadDCARB = extproc;

	return wglGetCurrentReadDCARB();
}

static HPBUFFERARB WINAPI InitCreatePbufferARB (HDC hDC, int iPixelFormat, int iWidth, int iHeight, const int *piAttribList)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglCreatePbufferARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglCreatePbufferARB = extproc;

	return wglCreatePbufferARB(hDC, iPixelFormat, iWidth, iHeight, piAttribList);
}

static HDC WINAPI InitGetPbufferDCARB (HPBUFFERARB hPbuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPbufferDCARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPbufferDCARB = extproc;

	return wglGetPbufferDCARB(hPbuffer);
}

static int WINAPI InitReleasePbufferDCARB (HPBUFFERARB hPbuffer, HDC hDC)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglReleasePbufferDCARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglReleasePbufferDCARB = extproc;

	return wglReleasePbufferDCARB(hPbuffer, hDC);
}

static BOOL WINAPI InitDestroyPbufferARB (HPBUFFERARB hPbuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDestroyPbufferARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglDestroyPbufferARB = extproc;

	return wglDestroyPbufferARB(hPbuffer);
}

static BOOL WINAPI InitQueryPbufferARB (HPBUFFERARB hPbuffer, int iAttribute, int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglQueryPbufferARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglQueryPbufferARB = extproc;

	return wglQueryPbufferARB(hPbuffer, iAttribute, piValue);
}

static BOOL WINAPI InitBindTexImageARB (HPBUFFERARB hPbuffer, int iBuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglBindTexImageARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglBindTexImageARB = extproc;

	return wglBindTexImageARB(hPbuffer, iBuffer);
}

static BOOL WINAPI InitReleaseTexImageARB (HPBUFFERARB hPbuffer, int iBuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglReleaseTexImageARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglReleaseTexImageARB = extproc;

	return wglReleaseTexImageARB(hPbuffer, iBuffer);
}

static BOOL WINAPI InitSetPbufferAttribARB (HPBUFFERARB hPbuffer, const int *piAttribList)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSetPbufferAttribARB");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSetPbufferAttribARB = extproc;

	return wglSetPbufferAttribARB(hPbuffer, piAttribList);
}

static GLboolean WINAPI InitCreateDisplayColorTableEXT (GLushort id)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglCreateDisplayColorTableEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglCreateDisplayColorTableEXT = extproc;

	return wglCreateDisplayColorTableEXT(id);
}

static GLboolean WINAPI InitLoadDisplayColorTableEXT (const GLushort *table, GLuint length)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglLoadDisplayColorTableEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglLoadDisplayColorTableEXT = extproc;

	return wglLoadDisplayColorTableEXT(table, length);
}

static GLboolean WINAPI InitBindDisplayColorTableEXT (GLushort id)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglBindDisplayColorTableEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglBindDisplayColorTableEXT = extproc;

	return wglBindDisplayColorTableEXT(id);
}

static VOID WINAPI InitDestroyDisplayColorTableEXT (GLushort id)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDestroyDisplayColorTableEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return;
	}

	wglDestroyDisplayColorTableEXT = extproc;

	wglDestroyDisplayColorTableEXT(id);
}

static const char * WINAPI InitGetExtensionsStringEXT (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetExtensionsStringEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetExtensionsStringEXT = extproc;

	return wglGetExtensionsStringEXT();
}

static BOOL WINAPI InitMakeContextCurrentEXT (HDC hDrawDC, HDC hReadDC, HGLRC hglrc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglMakeContextCurrentEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglMakeContextCurrentEXT = extproc;

	return wglMakeContextCurrentEXT(hDrawDC, hReadDC, hglrc);
}

static HDC WINAPI InitGetCurrentReadDCEXT (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetCurrentReadDCEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetCurrentReadDCEXT = extproc;

	return wglGetCurrentReadDCEXT();
}

static HPBUFFEREXT WINAPI InitCreatePbufferEXT (HDC hDC, int iPixelFormat, int iWidth, int iHeight, const int *piAttribList)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglCreatePbufferEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglCreatePbufferEXT = extproc;

	return wglCreatePbufferEXT(hDC, iPixelFormat, iWidth, iHeight, piAttribList);
}

static HDC WINAPI InitGetPbufferDCEXT (HPBUFFEREXT hPbuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPbufferDCEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPbufferDCEXT = extproc;

	return wglGetPbufferDCEXT(hPbuffer);
}

static int WINAPI InitReleasePbufferDCEXT (HPBUFFEREXT hPbuffer, HDC hDC)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglReleasePbufferDCEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglReleasePbufferDCEXT = extproc;

	return wglReleasePbufferDCEXT(hPbuffer, hDC);
}

static BOOL WINAPI InitDestroyPbufferEXT (HPBUFFEREXT hPbuffer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDestroyPbufferEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglDestroyPbufferEXT = extproc;

	return wglDestroyPbufferEXT(hPbuffer);
}

static BOOL WINAPI InitQueryPbufferEXT (HPBUFFEREXT hPbuffer, int iAttribute, int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglQueryPbufferEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglQueryPbufferEXT = extproc;

	return wglQueryPbufferEXT(hPbuffer, iAttribute, piValue);
}

static BOOL WINAPI InitGetPixelFormatAttribivEXT (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, int *piAttributes, int *piValues)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPixelFormatAttribivEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPixelFormatAttribivEXT = extproc;

	return wglGetPixelFormatAttribivEXT(hdc, iPixelFormat, iLayerPlane, nAttributes, piAttributes, piValues);
}

static BOOL WINAPI InitGetPixelFormatAttribfvEXT (HDC hdc, int iPixelFormat, int iLayerPlane, UINT nAttributes, int *piAttributes, FLOAT *pfValues)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetPixelFormatAttribfvEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetPixelFormatAttribfvEXT = extproc;

	return wglGetPixelFormatAttribfvEXT(hdc, iPixelFormat, iLayerPlane, nAttributes, piAttributes, pfValues);
}

static BOOL WINAPI InitChoosePixelFormatEXT (HDC hdc, const int *piAttribIList, const FLOAT *pfAttribFList, UINT nMaxFormats, int *piFormats, UINT *nNumFormats)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglChoosePixelFormatEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglChoosePixelFormatEXT = extproc;

	return wglChoosePixelFormatEXT(hdc, piAttribIList, pfAttribFList, nMaxFormats, piFormats, nNumFormats);
}

static BOOL WINAPI InitSwapIntervalEXT (int interval)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSwapIntervalEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSwapIntervalEXT = extproc;

	return wglSwapIntervalEXT(interval);
}

static int WINAPI InitGetSwapIntervalEXT (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetSwapIntervalEXT");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetSwapIntervalEXT = extproc;

	return wglGetSwapIntervalEXT();
}

static void* WINAPI InitAllocateMemoryNV (GLsizei size, GLfloat readfreq, GLfloat writefreq, GLfloat priority)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglAllocateMemoryNV");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglAllocateMemoryNV = extproc;

	return wglAllocateMemoryNV(size, readfreq, writefreq, priority);
}

static void WINAPI InitFreeMemoryNV (void *pointer)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglFreeMemoryNV");

	if (extproc == NULL) {
		_ASSERT(0);
		return;
	}

	wglFreeMemoryNV = extproc;

	wglFreeMemoryNV(pointer);
}

static BOOL WINAPI InitGetSyncValuesOML (HDC hdc, INT64 *ust, INT64 *msc, INT64 *sbc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetSyncValuesOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetSyncValuesOML = extproc;

	return wglGetSyncValuesOML(hdc, ust, msc, sbc);
}

static BOOL WINAPI InitGetMscRateOML (HDC hdc, INT32 *numerator, INT32 *denominator)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetMscRateOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetMscRateOML = extproc;

	return wglGetMscRateOML(hdc, numerator, denominator);
}

static INT64 WINAPI InitSwapBuffersMscOML (HDC hdc, INT64 target_msc, INT64 divisor, INT64 remainder)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSwapBuffersMscOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSwapBuffersMscOML = extproc;

	return wglSwapBuffersMscOML(hdc, target_msc, divisor, remainder);
}

static INT64 WINAPI InitSwapLayerBuffersMscOML (HDC hdc, int fuPlanes, INT64 target_msc, INT64 divisor, INT64 remainder)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSwapLayerBuffersMscOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSwapLayerBuffersMscOML = extproc;

	return wglSwapLayerBuffersMscOML(hdc, fuPlanes, target_msc, divisor, remainder);
}

static BOOL WINAPI InitWaitForMscOML (HDC hdc, INT64 target_msc, INT64 divisor, INT64 remainder, INT64 *ust, INT64 *msc, INT64 *sbc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglWaitForMscOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglWaitForMscOML = extproc;

	return wglWaitForMscOML(hdc, target_msc, divisor, remainder, ust, msc, sbc);
}

static BOOL WINAPI InitWaitForSbcOML (HDC hdc, INT64 target_sbc, INT64 *ust, INT64 *msc, INT64 *sbc)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglWaitForSbcOML");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglWaitForSbcOML = extproc;

	return wglWaitForSbcOML(hdc, target_sbc, ust, msc, sbc);
}

static BOOL WINAPI InitGetDigitalVideoParametersI3D (HDC hDC, int iAttribute, int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetDigitalVideoParametersI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetDigitalVideoParametersI3D = extproc;

	return wglGetDigitalVideoParametersI3D(hDC, iAttribute, piValue);
}

static BOOL WINAPI InitSetDigitalVideoParametersI3D (HDC hDC, int iAttribute, const int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSetDigitalVideoParametersI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSetDigitalVideoParametersI3D = extproc;

	return wglSetDigitalVideoParametersI3D(hDC, iAttribute, piValue);
}

static BOOL WINAPI InitGetGammaTableParametersI3D (HDC hDC, int iAttribute, int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGammaTableParametersI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGammaTableParametersI3D = extproc;

	return wglGetGammaTableParametersI3D(hDC, iAttribute, piValue);
}

static BOOL WINAPI InitSetGammaTableParametersI3D (HDC hDC, int iAttribute, const int *piValue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSetGammaTableParametersI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSetGammaTableParametersI3D = extproc;

	return wglSetGammaTableParametersI3D(hDC, iAttribute, piValue);
}

static BOOL WINAPI InitGetGammaTableI3D (HDC hDC, int iEntries, USHORT *puRed, USHORT *puGreen, USHORT *puBlue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGammaTableI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGammaTableI3D = extproc;

	return wglGetGammaTableI3D(hDC, iEntries, puRed, puGreen, puBlue);
}

static BOOL WINAPI InitSetGammaTableI3D (HDC hDC, int iEntries, const USHORT *puRed, const USHORT *puGreen, const USHORT *puBlue)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglSetGammaTableI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglSetGammaTableI3D = extproc;

	return wglSetGammaTableI3D(hDC, iEntries, puRed, puGreen, puBlue);
}

static BOOL WINAPI InitEnableGenlockI3D (HDC hDC)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglEnableGenlockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglEnableGenlockI3D = extproc;

	return wglEnableGenlockI3D(hDC);
}

static BOOL WINAPI InitDisableGenlockI3D (HDC hDC)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDisableGenlockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglDisableGenlockI3D = extproc;

	return wglDisableGenlockI3D(hDC);
}

static BOOL WINAPI InitIsEnabledGenlockI3D (HDC hDC, BOOL *pFlag)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglIsEnabledGenlockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglIsEnabledGenlockI3D = extproc;

	return wglIsEnabledGenlockI3D(hDC, pFlag);
}

static BOOL WINAPI InitGenlockSourceI3D (HDC hDC, UINT uSource)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGenlockSourceI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGenlockSourceI3D = extproc;

	return wglGenlockSourceI3D(hDC, uSource);
}

static BOOL WINAPI InitGetGenlockSourceI3D (HDC hDC, UINT *uSource)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGenlockSourceI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGenlockSourceI3D = extproc;

	return wglGetGenlockSourceI3D(hDC, uSource);
}

static BOOL WINAPI InitGenlockSourceEdgeI3D (HDC hDC, UINT uEdge)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGenlockSourceEdgeI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGenlockSourceEdgeI3D = extproc;

	return wglGenlockSourceEdgeI3D(hDC, uEdge);
}

static BOOL WINAPI InitGetGenlockSourceEdgeI3D (HDC hDC, UINT *uEdge)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGenlockSourceEdgeI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGenlockSourceEdgeI3D = extproc;

	return wglGetGenlockSourceEdgeI3D(hDC, uEdge);
}

static BOOL WINAPI InitGenlockSampleRateI3D (HDC hDC, UINT uRate)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGenlockSampleRateI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGenlockSampleRateI3D = extproc;

	return wglGenlockSampleRateI3D(hDC, uRate);
}

static BOOL WINAPI InitGetGenlockSampleRateI3D (HDC hDC, UINT *uRate)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGenlockSampleRateI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGenlockSampleRateI3D = extproc;

	return wglGetGenlockSampleRateI3D(hDC, uRate);
}

static BOOL WINAPI InitGenlockSourceDelayI3D (HDC hDC, UINT uDelay)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGenlockSourceDelayI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGenlockSourceDelayI3D = extproc;

	return wglGenlockSourceDelayI3D(hDC, uDelay);
}

static BOOL WINAPI InitGetGenlockSourceDelayI3D (HDC hDC, UINT *uDelay)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetGenlockSourceDelayI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetGenlockSourceDelayI3D = extproc;

	return wglGetGenlockSourceDelayI3D(hDC, uDelay);
}

static BOOL WINAPI InitQueryGenlockMaxSourceDelayI3D (HDC hDC, UINT *uMaxLineDelay, UINT *uMaxPixelDelay)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglQueryGenlockMaxSourceDelayI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglQueryGenlockMaxSourceDelayI3D = extproc;

	return wglQueryGenlockMaxSourceDelayI3D(hDC, uMaxLineDelay, uMaxPixelDelay);
}

static LPVOID WINAPI InitCreateImageBufferI3D (HDC hDC, DWORD dwSize, UINT uFlags)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglCreateImageBufferI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglCreateImageBufferI3D = extproc;

	return wglCreateImageBufferI3D(hDC, dwSize, uFlags);
}

static BOOL WINAPI InitDestroyImageBufferI3D (HDC hDC, LPVOID pAddress)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDestroyImageBufferI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglDestroyImageBufferI3D = extproc;

	return wglDestroyImageBufferI3D(hDC, pAddress);
}

static BOOL WINAPI InitAssociateImageBufferEventsI3D (HDC hDC, const HANDLE *pEvent, const LPVOID *pAddress, const DWORD *pSize, UINT count)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglAssociateImageBufferEventsI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglAssociateImageBufferEventsI3D = extproc;

	return wglAssociateImageBufferEventsI3D(hDC, pEvent, pAddress, pSize, count);
}

static BOOL WINAPI InitReleaseImageBufferEventsI3D (HDC hDC, const LPVOID *pAddress, UINT count)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglReleaseImageBufferEventsI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglReleaseImageBufferEventsI3D = extproc;

	return wglReleaseImageBufferEventsI3D(hDC, pAddress, count);
}

static BOOL WINAPI InitEnableFrameLockI3D (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglEnableFrameLockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglEnableFrameLockI3D = extproc;

	return wglEnableFrameLockI3D();
}

static BOOL WINAPI InitDisableFrameLockI3D (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglDisableFrameLockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglDisableFrameLockI3D = extproc;

	return wglDisableFrameLockI3D();
}

static BOOL WINAPI InitIsEnabledFrameLockI3D (BOOL *pFlag)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglIsEnabledFrameLockI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglIsEnabledFrameLockI3D = extproc;

	return wglIsEnabledFrameLockI3D(pFlag);
}

static BOOL WINAPI InitQueryFrameLockMasterI3D (BOOL *pFlag)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglQueryFrameLockMasterI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglQueryFrameLockMasterI3D = extproc;

	return wglQueryFrameLockMasterI3D(pFlag);
}

static BOOL WINAPI InitGetFrameUsageI3D (float *pUsage)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglGetFrameUsageI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglGetFrameUsageI3D = extproc;

	return wglGetFrameUsageI3D(pUsage);
}

static BOOL WINAPI InitBeginFrameTrackingI3D (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglBeginFrameTrackingI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglBeginFrameTrackingI3D = extproc;

	return wglBeginFrameTrackingI3D();
}

static BOOL WINAPI InitEndFrameTrackingI3D (void)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglEndFrameTrackingI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglEndFrameTrackingI3D = extproc;

	return wglEndFrameTrackingI3D();
}

static BOOL WINAPI InitQueryFrameTrackingI3D (DWORD *pFrameCount, DWORD *pMissedFrames, float *pLastMissedUsage)
{
	void *extproc;

	extproc = (void *) wglGetProcAddress("wglQueryFrameTrackingI3D");

	if (extproc == NULL) {
		_ASSERT(0);
		return 0;
	}

	wglQueryFrameTrackingI3D = extproc;

	return wglQueryFrameTrackingI3D(pFrameCount, pMissedFrames, pLastMissedUsage);
}

_GLextensionProcs _extensionProcs = {
	InitCreateBufferRegionARB,
	InitDeleteBufferRegionARB,
	InitSaveBufferRegionARB,
	InitRestoreBufferRegionARB,
	InitGetExtensionsStringARB,
	InitGetPixelFormatAttribivARB,
	InitGetPixelFormatAttribfvARB,
	InitChoosePixelFormatARB,
	InitMakeContextCurrentARB,
	InitGetCurrentReadDCARB,
	InitCreatePbufferARB,
	InitGetPbufferDCARB,
	InitReleasePbufferDCARB,
	InitDestroyPbufferARB,
	InitQueryPbufferARB,
	InitBindTexImageARB,
	InitReleaseTexImageARB,
	InitSetPbufferAttribARB,
	InitCreateDisplayColorTableEXT,
	InitLoadDisplayColorTableEXT,
	InitBindDisplayColorTableEXT,
	InitDestroyDisplayColorTableEXT,
	InitGetExtensionsStringEXT,
	InitMakeContextCurrentEXT,
	InitGetCurrentReadDCEXT,
	InitCreatePbufferEXT,
	InitGetPbufferDCEXT,
	InitReleasePbufferDCEXT,
	InitDestroyPbufferEXT,
	InitQueryPbufferEXT,
	InitGetPixelFormatAttribivEXT,
	InitGetPixelFormatAttribfvEXT,
	InitChoosePixelFormatEXT,
	InitSwapIntervalEXT,
	InitGetSwapIntervalEXT,
	InitAllocateMemoryNV,
	InitFreeMemoryNV,
	InitGetSyncValuesOML,
	InitGetMscRateOML,
	InitSwapBuffersMscOML,
	InitSwapLayerBuffersMscOML,
	InitWaitForMscOML,
	InitWaitForSbcOML,
	InitGetDigitalVideoParametersI3D,
	InitSetDigitalVideoParametersI3D,
	InitGetGammaTableParametersI3D,
	InitSetGammaTableParametersI3D,
	InitGetGammaTableI3D,
	InitSetGammaTableI3D,
	InitEnableGenlockI3D,
	InitDisableGenlockI3D,
	InitIsEnabledGenlockI3D,
	InitGenlockSourceI3D,
	InitGetGenlockSourceI3D,
	InitGenlockSourceEdgeI3D,
	InitGetGenlockSourceEdgeI3D,
	InitGenlockSampleRateI3D,
	InitGetGenlockSampleRateI3D,
	InitGenlockSourceDelayI3D,
	InitGetGenlockSourceDelayI3D,
	InitQueryGenlockMaxSourceDelayI3D,
	InitCreateImageBufferI3D,
	InitDestroyImageBufferI3D,
	InitAssociateImageBufferEventsI3D,
	InitReleaseImageBufferEventsI3D,
	InitEnableFrameLockI3D,
	InitDisableFrameLockI3D,
	InitIsEnabledFrameLockI3D,
	InitQueryFrameLockMasterI3D,
	InitGetFrameUsageI3D,
	InitBeginFrameTrackingI3D,
	InitEndFrameTrackingI3D,
	InitQueryFrameTrackingI3D,
};

#endif /* _WIN32 */

#endif /* USE_EXT_IF */
